==> zio-aws-kinesisanalyticsv2_2.13-5.17.128.1-sources.jar: zio/aws/kinesisanalyticsv2/model/ApplicationSnapshotConfigurationUpdate.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.BooleanObject
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ApplicationSnapshotConfigurationUpdate(
    snapshotsEnabledUpdate: BooleanObject
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate = {
    import ApplicationSnapshotConfigurationUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
      .builder()
      .snapshotsEnabledUpdate(
        BooleanObject.unwrap(snapshotsEnabledUpdate): java.lang.Boolean
      )
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
      .wrap(buildAwsValue())
}
object ApplicationSnapshotConfigurationUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate =
      zio.aws.kinesisanalyticsv2.model
        .ApplicationSnapshotConfigurationUpdate(snapshotsEnabledUpdate)
    def snapshotsEnabledUpdate: BooleanObject
    def getSnapshotsEnabledUpdate: ZIO[Any, Nothing, BooleanObject] =
      ZIO.succeed(snapshotsEnabledUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
  ) extends zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate.ReadOnly {
    override val snapshotsEnabledUpdate: BooleanObject =
      zio.aws.kinesisanalyticsv2.model.primitives
        .BooleanObject(impl.snapshotsEnabledUpdate())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
  ): zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_2.13-5.19.12.1-sources.jar: zio/aws/kinesisanalyticsv2/model/ApplicationSnapshotConfigurationUpdate.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.BooleanObject
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ApplicationSnapshotConfigurationUpdate(
    snapshotsEnabledUpdate: BooleanObject
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate = {
    import ApplicationSnapshotConfigurationUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
      .builder()
      .snapshotsEnabledUpdate(snapshotsEnabledUpdate: java.lang.Boolean)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
      .wrap(buildAwsValue())
}
object ApplicationSnapshotConfigurationUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate =
      zio.aws.kinesisanalyticsv2.model
        .ApplicationSnapshotConfigurationUpdate(snapshotsEnabledUpdate)
    def snapshotsEnabledUpdate: BooleanObject
    def getSnapshotsEnabledUpdate: ZIO[Any, Nothing, BooleanObject] =
      ZIO.succeed(snapshotsEnabledUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
  ) extends zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate.ReadOnly {
    override val snapshotsEnabledUpdate: BooleanObject =
      impl.snapshotsEnabledUpdate(): BooleanObject
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate
  ): zio.aws.kinesisanalyticsv2.model.ApplicationSnapshotConfigurationUpdate.ReadOnly =
    new Wrapper(impl)
}
